=======
History
=======

0.2.0 (2020-02-18)
------------------
* Add support to process coco dataset


0.2.1 (2020-02-28)
------------------
* add support to download files and archives from the web and google drive